addCurrency method
Add a new Currency to the inventory or update the existing Currency inventory by increasing the amount by quantity
Implementation
addCurrency({required Currency currency, int quantity = 1}) {
currencies.update(currency, (value) => value + quantity,
ifAbsent: () => quantity);
}